@@ -3,7 +3,7 @@
 # @Date:   2020-03-10 14:52:05
 # @E-mail: maoyongfan@163.com
 # @Last Modified by:   yongfanmao
-# @Last Modified time: 2020-10-21 18:24:06
+# @Last Modified time: 2020-10-29 13:45:35
 
 from robot.api import logger
 from HelloBikeLibrary.request import Request
@@ -42,7 +42,8 @@ class Common(object):
 			app登陆认证
 			mobilePhone 登陆手机号
 			env 不传默认为uat
-			返回token,guid
+			支持pre,uat,fat登录```
+			返回token,guid,ticket
 		"""
 		
 		
@@ -88,7 +89,7 @@ class Common(object):
 			if content.get("code") == 0:
 				if content.get('data').get('token'):
 					logger.info(content.get('data'))
-					return content.get('data').get('token'),content.get('data').get('guid')
+					return content.get('data').get('token'),content.get('data').get('guid'),content.get('data').get('ticket','')
 			else:
 				return "网络异常" + str(content)
 		else:
@@ -118,7 +119,7 @@ class Common(object):
 
 if __name__ == '__main__':
 	com = Common()
-	# print(com.login_auth_app("12010002002",env="uat"))
-	print(com.login_auth_app("17521766998",env="pre"))
+	print(com.login_auth_app("12010002002",env="uat"))
+	# print(com.login_auth_app("17521766998",env="pre"))
 	# print(com.login_auth_app("12010060001",env="uat"))
 
